@@ -238,7 +238,7 @@ package Chj::TEST::Test::Builder {
 }
 
 
-use FP::DumperEqual;
+use FP::Equal qw(relaxedequal);
 use FP::Show;
 
 sub eval_test ($$) {
@@ -275,8 +275,7 @@ sub eval_test ($$) {
 
     my $location= "at $filename line $line";
     my $nicelocation= "line $line";
-    if (! $maybe_e and
-        dumperequal($got, $res) or dumperequal_utf8($got, $res)) {
+    if (! $maybe_e and relaxedequal($got, $res)) {
         style_switch +{
             old=> sub {
                 print "ok\n";
@@ -310,7 +309,11 @@ sub eval_test ($$) {
                 # *remains* blessed!
                 local $Chj::TEST::Test::Builder::fake_caller=
                     [$package, $filename, $line];
-                $tb->ok( 0, $nicelocation);
+                #$tb->ok( 0, $nicelocation);
+                # On some systems (Test::Builder versions?), the above
+                # hackery doesn't work (sigh, move to Test2::*?), thus
+                # provide the full location info anyway:
+                $tb->ok( 0, $location);
 
                 if (defined $maybe_e) {
                     diag("Exception: $$maybe_e[0]");
