@@ -239,16 +239,20 @@ tests_for \&memoizing;
 
 {
     my $tdir= ".FP-Memoizing-tests";
+
     TEST {
         mkdir $tdir;
     } 1;
+
     tests_for sub {
         my ($f)=@_;
         &memoizing_to_dir ($tdir, $f);
     };
         
-    TEST { system qw(rm -rf --), $tdir }
-      0;
+    TEST {
+        require File::Path;
+        File::Path::remove_tree $tdir;
+    } 6;
 }
 
 1
