@@ -60,7 +60,7 @@ C<:chars>: L<FP::Char>
 
 C<:csv>: L<FP::Text::CSV>
 
-C<:datastructures>: C<:chars>, C<:maps>, C<:sequences>, C<:sets>, C<:tries>
+C<:datastructures>: C<:chars>, C<:maps>, C<:numbers>, C<:sequences>, C<:sets>, C<:tries>
 
 C<:dbi>: L<FP::DBI>
 
@@ -86,6 +86,8 @@ C<:maps>: L<FP::Hash>
 
 C<:most>: C<:autobox>, C<:datastructures>, C<:debug>, C<:equal>, C<:failure>, C<:functions>, C<:lazy>, C<:show>
 
+C<:numbers>: L<FP::BigInt>
+
 C<:path>: L<FP::Path>
 
 C<:pxml>: L<PXML::Serialize>, L<PXML::Util>, L<PXML::XHTML>
@@ -126,7 +128,7 @@ package FunctionalPerl;
 
 use strict; use warnings; use warnings FATAL => 'uninitialized';
 
-our $VERSION= "0.72.11";
+our $VERSION= "0.72.12";
 
 
 # Export tag to modules and/or other tags; each module will be
@@ -157,6 +159,7 @@ our $export_desc=
     ":git"=> [qw(FP::Git::Repository)],
     ":pxml"=> [qw(PXML::Util PXML::XHTML PXML::Serialize)],
 
+    ":numbers"=> [qw(FP::BigInt)],
     ":chars"=> [qw(FP::Char)],
     ":sequences"=> [qw(FP::List FP::StrictList FP::MutableArray
                        FP::Array FP::Array_sort
@@ -165,7 +168,7 @@ our $export_desc=
     ":maps"=> [qw(FP::Hash)],
     ":sets"=> [qw(FP::HashSet FP::OrderedCollection)],
     ":tries"=> [qw(FP::Trie)],
-    ":datastructures"=> [qw(:chars :sequences :maps :sets :tries)],
+    ":datastructures"=> [qw(:chars :numbers :sequences :maps :sets :tries)],
 
     ":io"=> [qw(Chj::xIO Chj::xopen Chj::xtmpfile= Chj::tempdir
                 Chj::xpipe= Chj::xoutpipe= Chj::xopendir= Chj::xperlfunc
